pub struct GlobalOptions {Show 17 fields
pub full_gitmoji: bool,
pub context: Option<String>,
pub skip_confirmation: bool,
pub show_prompt: bool,
pub no_pre_hooks: bool,
pub no_post_hooks: bool,
pub generate_count: u8,
pub clipboard: bool,
pub exclude_files: Option<Vec<String>>,
pub timing: bool,
pub strip_thinking: bool,
pub print_message: bool,
pub output_format: OutputFormat,
pub prompt_file: Option<String>,
pub dry_run: bool,
pub edit: bool,
pub skill: Option<String>,
}Fields
full_gitmoji: boolUse full GitMoji specification
context: Option<String>Additional user input context for the commit message
skip_confirmation: boolSkip commit confirmation prompt
show_prompt: boolShow the prompt that would be used without generating commit
no_pre_hooks: boolDisable running pre-hooks
no_post_hooks: boolDisable running post-hooks
generate_count: u8Number of commit message variations to generate (1-5)
clipboard: boolCopy generated message to clipboard instead of committing
exclude_files: Option<Vec<String>>Exclude specific files from the diff sent to AI
timing: boolShow detailed timing information
strip_thinking: boolStrip
print_message: boolOutput commit message to stdout instead of committing (for hooks)
output_format: OutputFormatOutput format (pretty, json, markdown)
prompt_file: Option<String>Use a custom prompt template file
dry_run: boolPreview the generated commit message without committing (dry-run mode)
edit: boolOpen the generated message in $EDITOR before committing
skill: Option<String>Use a specific skill for commit generation